@@ -90,7 +90,7 @@ import com.openexchange.groupware.tasks.Task;
 
 /**
  * @author Francisco Laguna <francisco.laguna@open-xchange.com>
- * @author Tobias Prinz <tobias.prinz@open-xchange.com> ( hacks to fix bug 11958, which is ical4j ignoring timezone information if given after event data )
+ * @author Tobias Prinz <tobias.prinz@open-xchange.com> (bug 11958, 16367)
  */
 public class ICal4JParser implements ICalParser {
 
@@ -227,7 +227,7 @@ public class ICal4JParser implements ICalParser {
 
 
     private static final TimeZone determineTimeZone(final CalendarComponent component,
-        final TimeZone defaultTZ) throws ConversionError {
+        final TimeZone defaultTZ){
         for (final String name : new String[] { DtStart.DTSTART, DtEnd.DTEND, Due.DUE, Completed.COMPLETED }) {
             final DateProperty dateProp = (DateProperty) component.getProperty(name);
             if (dateProp != null) {
@@ -310,7 +310,10 @@ public class ICal4JParser implements ICalParser {
             		}
             	}
             }
-            return builder.build(new StringReader(chunk.toString())); // FIXME: Encoding!
+            StringReader chunkedReader = new StringReader(
+                workaroundFor16613(
+                    workaroundFor16367(chunk.toString()))); // FIXME: Encoding!
+            return builder.build(chunkedReader); 
         } catch (final IOException e) {
             //IGNORE
         } catch (final ParserException e) {
@@ -320,4 +323,21 @@ public class ICal4JParser implements ICalParser {
         return null;
     }
 
+   
+    private String workaroundFor16367(String input) {
+        /* Bug in MS Exchange: If you use a CN element, it must have a value.
+         * MS Exchange has an empty value, which we now replace properly. 
+         */
+        return input.replaceAll("CN=:", "CN=\"\":");
+    }
+    
+    private String workaroundFor16613(String input) {
+        /*
+         * Bug in Groupwise: There is no attribute ID for ATTACH. Experimental
+         * ones are allowed, but they would start with X-GW for Groupwise.
+         * We ignore those.
+         */
+        return input.replaceAll("\nATTACH(.*?);ID=(.+?)([:;])" , "\nATTACH$1$3");
+    }
+
 }
\ No newline at end of file
