@@ -69,7 +69,6 @@ import net.fortuna.ical4j.model.parameter.PartStat;
 import net.fortuna.ical4j.model.parameter.Role;
 import net.fortuna.ical4j.model.parameter.Rsvp;
 import net.fortuna.ical4j.model.property.Attendee;
-import net.fortuna.ical4j.model.property.Comment;
 import net.fortuna.ical4j.model.property.Resources;
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
@@ -89,6 +88,10 @@ import com.openexchange.groupware.container.participants.ConfirmableParticipant;
 import com.openexchange.groupware.contexts.Context;
 import com.openexchange.groupware.ldap.User;
 import com.openexchange.groupware.ldap.UserException;
+import com.openexchange.groupware.notify.NotificationConfig;
+import com.openexchange.groupware.notify.NotificationConfig.NotificationProperty;
+import com.openexchange.groupware.userconfiguration.UserConfigurationException;
+import com.openexchange.mail.usersetting.UserSettingMailStorage;
 import com.openexchange.resource.Resource;
 import com.openexchange.resource.ResourceException;
 import com.openexchange.server.ServiceException;
@@ -167,8 +170,20 @@ public class Participants<T extends CalendarComponent, U extends CalendarObject>
     protected void addUserAttendee(int index, UserParticipant userParticipant, Context ctx, T component, U obj) throws ConversionError {
         final Attendee attendee = new Attendee();
         try {
-            String address = resolveUserMail(index, userParticipant, ctx);
-            attendee.setValue("mailto:"+ address);
+            String address;
+            //This sets the attendees email-addresses to their DefaultSenderAddress if configured via com.openexchange.notification.fromSource in notification.properties
+            String senderSource = NotificationConfig.getProperty(NotificationProperty.FROM_SOURCE, "primaryMail");
+            if ("defaultSenderAddress".equals(senderSource)) { 
+                try {
+                    address = UserSettingMailStorage.getInstance().loadUserSettingMail(userParticipant.getIdentifier(), ctx).getSendAddr();
+                } catch (UserConfigurationException e) {
+                    LOG.error(e.getMessage(), e);
+                    address = resolveUserMail(index, userParticipant, ctx);
+                }
+            } else {
+                address = resolveUserMail(index, userParticipant, ctx);
+            }
+            attendee.setValue("mailto:" + address);
             ParameterList parameters = attendee.getParameters();
             parameters.add(Role.REQ_PARTICIPANT);
             parameters.add(CuType.INDIVIDUAL);
@@ -234,7 +249,6 @@ public class Participants<T extends CalendarComponent, U extends CalendarObject>
                     mails.put(mail, icalP);
                 }
             }
-
         }
 
         List<User> users;
@@ -248,15 +262,22 @@ public class Participants<T extends CalendarComponent, U extends CalendarObject>
 
         for(final User user : users) {
             UserParticipant up = new UserParticipant(user.getId());
-            ICalParticipant icalP = mails.get(user.getMail());
-            
+            ICalParticipant icalP = null;
+            for (String alias: user.getAliases()) {
+                icalP = mails.get(alias);
+                if (icalP != null) {
+                    mails.remove(alias);
+                    break;
+                }
+            }
+            if (icalP == null)
+                throw new IllegalStateException("Should not be possible to find a user by it's alias and then be unable to remove that alias from list");
             if (icalP.message != null)
                 up.setConfirmMessage(icalP.message);
             if (icalP.status != -1)
                 up.setConfirm(icalP.status);
             
-            cObj.addParticipant( new UserParticipant(user.getId()) );
-            mails.remove(user.getMail());
+            cObj.addParticipant( new UserParticipant(user.getId()) ); //TODO Is that a bug? Which one?
         }
 
         List<ConfirmableParticipant> confirmableParticipants = new ArrayList<ConfirmableParticipant>();
